<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en" sourcelanguage="en">
<context>
    <name>SelectPathWidget</name>
    <message>
        <location filename="../selectpathwidget.cpp" line="33"/>
        <location filename="../selectpathwidget.cpp" line="65"/>
        <source>Picture path</source>
        <translation>Picture path</translation>
    </message>
    <message>
        <location filename="../selectpathwidget.cpp" line="40"/>
        <source>Select a path of pictures</source>
        <translation>Select a path of pictures</translation>
    </message>
</context>
<context>
    <name>TimeIntervalWidget</name>
    <message>
        <location filename="../timeintervalwidget.cpp" line="32"/>
        <source>Time interval(s)</source>
        <translation>Time interval(s)</translation>
    </message>
    <message>
        <location filename="../timeintervalwidget.cpp" line="34"/>
        <source>Range</source>
        <translation>Range</translation>
    </message>
</context>
</TS>
